@@ -45,20 +45,21 @@
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "preferencesdialog.hpp"
+#include "recentchanges.hpp"
 #include "remotecontrolproxy.hpp"
 #include "utils.hpp"
+#include "tagmanager.hpp"
 #include "xkeybinder.hpp"
 #include "dbus/remotecontrol.hpp"
 #include "dbus/remotecontrolclient.hpp"
 #include "sharp/streamreader.hpp"
 #include "sharp/files.hpp"
+#include "notebooks/notebookmanager.hpp"
 #include "synchronization/syncmanager.hpp"
 
 
 namespace gnote {
 
-  Gnote *Gnote::s_obj = NULL;
-
   Gnote::Gnote()
     : Gtk::Application("org.gnome.Gnote", Gio::APPLICATION_HANDLES_COMMAND_LINE)
     , m_manager(NULL)
@@ -125,7 +126,7 @@ namespace gnote {
       cmd_line.execute();
     }
     else {
-      new_main_window()->present();
+      new_main_window().present();
     }
 
     return 0;
@@ -144,10 +145,16 @@ namespace gnote {
   void Gnote::common_init()
   {
     std::string note_path = get_note_path(cmd_line.note_path());
+
+    //create singleton objects
+    new TagManager;
+    new Preferences;
     m_manager = new NoteManager(note_path, sigc::mem_fun(*this, &Gnote::start_note_created));
+    new notebooks::NotebookManager(default_note_manager());
     m_keybinder = new XKeybinder();
-    ActionManager::obj().load_interface();
-    sync::SyncManager::init();
+    (new ActionManager)->load_interface();
+    sync::SyncManager::init(default_note_manager());
+
     setup_global_actions();
     m_manager->get_addin_manager().initialize_application_addins();
   }
@@ -155,7 +162,7 @@ namespace gnote {
 
   void Gnote::end_main(bool bus_acquired, bool name_acquired)
   {
-    ActionManager & am(ActionManager::obj());
+    IActionManager & am(IActionManager::obj());
     if((m_is_background = cmd_line.background())) {
       am["QuitGNoteAction"]->set_visible(false);
     }
@@ -201,7 +208,7 @@ namespace gnote {
       new_main_window();
     }
     else {
-      am["ShowSearchAllNotesAction"]->activate();
+      get_main_window().present();
     }
   }
 
@@ -244,7 +251,7 @@ namespace gnote {
 
     if(!m_tray_icon) {
       // Create the tray icon and run the main loop
-      m_tray_icon = Glib::RefPtr<TrayIcon>(new TrayIcon(default_note_manager()));
+      m_tray_icon = Glib::RefPtr<TrayIcon>(new TrayIcon(keybinder(), default_note_manager()));
       m_tray = m_tray_icon->tray();
     }
 
@@ -265,8 +272,8 @@ namespace gnote {
   void Gnote::register_object()
   {
     RemoteControlProxy::register_object(Gio::DBus::Connection::get_sync(Gio::DBus::BUS_TYPE_SESSION),
-                                        Gnote::obj().default_note_manager(),
-                                        sigc::mem_fun(Gnote::obj(), &Gnote::end_main));
+                                        default_note_manager(),
+                                        sigc::mem_fun(*this, &Gnote::end_main));
   }
 
 
@@ -292,7 +299,7 @@ namespace gnote {
 
   void Gnote::setup_global_actions()
   {
-    ActionManager & am(ActionManager::obj());
+    IActionManager & am(IActionManager::obj());
     am["QuitGNoteAction"]->signal_activate()
       .connect(sigc::mem_fun(*this, &Gnote::quit));
     am["ShowPreferencesAction"]->signal_activate().connect(
@@ -322,7 +329,7 @@ namespace gnote {
   void Gnote::on_show_preferences_action(const Glib::VariantBase&)
   {
     if(!m_prefsdlg) {
-      m_prefsdlg = new PreferencesDialog(m_manager->get_addin_manager());
+      m_prefsdlg = new PreferencesDialog(default_note_manager());
       m_prefsdlg->signal_response().connect(
         sigc::mem_fun(*this, &Gnote::on_preferences_response));
     }
@@ -382,30 +389,34 @@ namespace gnote {
     about.set_documenters(documenters);
     about.set_translator_credits(translators);
 //      about.set_icon_name("gnote");
-    NoteRecentChanges *recent_changes = get_main_window();
-    if(recent_changes && recent_changes->get_visible()) {
-      about.set_transient_for(*recent_changes);
-      recent_changes->present();
+    MainWindow & recent_changes = get_main_window();
+    if(recent_changes.get_visible()) {
+      about.set_transient_for(recent_changes);
+      recent_changes.present();
     }
     about.run();
   }
 
-  NoteRecentChanges *Gnote::new_main_window()
+  MainWindow & Gnote::new_main_window()
   {
     NoteRecentChanges *win = new NoteRecentChanges(default_note_manager());
     win->signal_hide().connect(sigc::mem_fun(*this, &Gnote::on_main_window_closed));
     add_window(*win);
-    return win;
+    return *win;
   }
 
-  NoteRecentChanges *Gnote::get_main_window()
+  MainWindow & Gnote::get_main_window()
   {
+    MainWindow *rc = get_active_window();
+    if(rc) {
+      return *rc;
+    }
     std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
     for(std::vector<Gtk::Window*>::iterator iter = windows.begin();
         iter != windows.end(); ++iter) {
-      NoteRecentChanges *rc = dynamic_cast<NoteRecentChanges*>(*iter);
+      rc = dynamic_cast<MainWindow*>(*iter);
       if(rc) {
-        return rc;
+        return *rc;
       }
     }
 
@@ -420,22 +431,22 @@ namespace gnote {
     }
   }
 
-  NoteRecentChanges *Gnote::get_window_for_note()
+  MainWindow & Gnote::get_window_for_note()
   {
     std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
-    NoteRecentChanges *window = NULL;
+    MainWindow *window = NULL;
     for(std::vector<Gtk::Window*>::iterator iter = windows.begin(); iter != windows.end(); ++iter) {
-      NoteRecentChanges *rc = dynamic_cast<NoteRecentChanges*>(*iter);
+      MainWindow *rc = dynamic_cast<MainWindow*>(*iter);
       if(rc) {
         window = rc;
         if(rc->get_visible()) {
-          return rc;
+          return *rc;
         }
       }
     }
 
     if(window) {
-      return window;
+      return *window;
     }
 
     return new_main_window();
@@ -443,15 +454,15 @@ namespace gnote {
 
   void Gnote::open_search_all()
   {
-    NoteRecentChanges *main_window = get_main_window();
-    main_window->present_search();
-    main_window->present();
+    MainWindow & main_window = get_main_window();
+    main_window.present_search();
+    main_window.present();
   }
 
   void Gnote::open_note_sync_window(const Glib::VariantBase&)
   {
     if(m_sync_dlg == 0) {
-      m_sync_dlg = sync::SyncDialog::create();
+      m_sync_dlg = sync::SyncDialog::create(default_note_manager());
       m_sync_dlg->signal_response().connect(sigc::mem_fun(*this, &Gnote::on_sync_dialog_response));
     }
 
@@ -468,7 +479,7 @@ namespace gnote {
 
   void Gnote::make_app_actions()
   {
-    ActionManager & am(ActionManager::obj());
+    IActionManager & am(IActionManager::obj());
     am.get_app_action("new-note")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_note_app_action));
     am.get_app_action("new-window")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_window_action));
     am.get_app_action("show-preferences")->signal_activate().connect(
@@ -478,7 +489,7 @@ namespace gnote {
     am.get_app_action("about")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_about_action));
     am.get_app_action("quit")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_quit_gnote_action));
 
-    add_app_actions(am.get_app_actions());
+    add_app_actions(static_cast<ActionManager &>(am).get_app_actions());
   }
 
 
@@ -493,16 +504,16 @@ namespace gnote {
 
   void Gnote::on_new_window_action(const Glib::VariantBase&)
   {
-    new_main_window()->present();
+    new_main_window().present();
   }
 
 
-  NoteRecentChanges *Gnote::get_active_window()
+  MainWindow *Gnote::get_active_window()
   {
     std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
     for(std::vector<Gtk::Window*>::iterator iter = windows.begin(); iter != windows.end(); ++iter) {
       if((*iter)->property_is_active()) {
-        return dynamic_cast<NoteRecentChanges*>(*iter);
+        return dynamic_cast<MainWindow*>(*iter);
       }
     }
 
@@ -512,62 +523,32 @@ namespace gnote {
 
   void Gnote::on_new_note_app_action(const Glib::VariantBase&)
   {
-    NoteRecentChanges *rc = get_active_window();
+    MainWindow *rc = get_active_window();
     if(rc) {
       rc->new_note();
     }
     else {
-      NoteRecentChanges *recent_changes = get_main_window();
-      recent_changes->new_note();
-      recent_changes->present();
+      MainWindow & recent_changes = get_main_window();
+      recent_changes.new_note();
+      recent_changes.present();
     }
   }
 
 
   void Gnote::open_note(const Note::Ptr & note)
   {
-    NoteRecentChanges *main_window = get_window_for_note();
-    main_window->present_note(note);
-    main_window->present();
+    MainWindow & main_window = get_window_for_note();
+    main_window.present_note(note);
+    main_window.present();
   }
 
 
   void Gnote::make_app_menu()
   {
-    set_app_menu(ActionManager::obj().get_app_menu());
+    set_app_menu(static_cast<ActionManager &>(IActionManager::obj()).get_app_menu());
   }
 
 
-  std::string Gnote::cache_dir()
-  {
-    return Glib::get_user_cache_dir() + "/gnote";
-  }
-
-
-  std::string Gnote::conf_dir()
-  {
-    return Glib::get_user_config_dir() + "/gnote";
-  }
-
-
-  std::string Gnote::data_dir()
-  {
-    return Glib::get_user_data_dir() + "/gnote";
-  }
-
-
-  std::string Gnote::old_note_dir()
-  {
-    std::string home_dir = Glib::get_home_dir();
-
-    if (home_dir.empty())
-      home_dir = Glib::get_current_dir();
-
-    return home_dir + "/.gnote";
-  }
-
-
-
   GnoteCommandLine::GnoteCommandLine()
     : m_context(g_option_context_new("Foobar"))
     , m_use_panel(false)
@@ -675,7 +656,7 @@ namespace gnote {
       else {
         execute(remote);
       }
-      Gnote::obj().quit();
+      static_cast<Gnote&>(Gnote::obj()).quit();
     }
     return 0;
   }
