@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -31,10 +31,9 @@
 #include <gtkmm/icontheme.h>
 #include <gtkmm/statusicon.h>
 
-#include "base/singleton.hpp"
 #include "actionmanager.hpp"
+#include "ignote.hpp"
 #include "keybinder.hpp"
-#include "recentchanges.hpp"
 #include "remotecontrolproxy.hpp"
 #include "tray.hpp"
 #include "synchronization/syncdialog.hpp"
@@ -100,16 +99,12 @@ private:
 
 class Gnote
   : public Gtk::Application
+  , public IGnote
 {
 public:
-  static Gnote& obj()
-    {
-      return *s_obj;
-    }
   static Glib::RefPtr<Gnote> create()
     {
-      s_obj = new Gnote;
-      return Glib::RefPtr<Gnote>(s_obj);
+      return Glib::RefPtr<Gnote>(new Gnote);
     }
 
   ~Gnote();
@@ -131,17 +126,12 @@ public:
   void on_show_preferences_action(const Glib::VariantBase&);
   void on_show_help_action(const Glib::VariantBase&);
   void on_show_about_action(const Glib::VariantBase&);
-  NoteRecentChanges *new_main_window();
-  NoteRecentChanges *get_main_window();
-  NoteRecentChanges *get_window_for_note();
-  void open_search_all();
+  virtual MainWindow & new_main_window();
+  virtual MainWindow & get_main_window();
+  virtual MainWindow & get_window_for_note();
+  virtual void open_search_all();
   void open_note_sync_window(const Glib::VariantBase&);
 
-  static std::string cache_dir();
-  static std::string conf_dir();
-  static std::string data_dir();
-  static std::string old_note_dir();
-
   bool tray_icon_showing()
     {
       return m_tray_icon && m_tray_icon->is_embedded() && m_tray_icon->get_visible();
@@ -158,21 +148,13 @@ public:
     {
       m_tray = tray;
     }
-  sigc::signal<void> signal_quit;
   static void register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish);
-  static void register_object();
-  sync::SyncDialog::Ptr sync_dialog()
-    {
-      return m_sync_dlg;
-    }
-  void open_note(const Note::Ptr & note);
+  virtual void open_note(const Note::Ptr & note);
 protected:
   virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line);
   virtual void on_startup();
   virtual void on_window_removed(Gtk::Window *window);
 private:
-  static Gnote *s_obj;
-
   Gnote();
   void start_note_created(const Note::Ptr & start_note);
   std::string get_note_path(const std::string & override_path);
@@ -186,8 +168,9 @@ private:
   void make_app_menu();
   void on_new_window_action(const Glib::VariantBase&);
   void on_new_note_app_action(const Glib::VariantBase&);
-  NoteRecentChanges *get_active_window();
+  MainWindow *get_active_window();
   bool show_tray_icon_timeout();
+  void register_object();
 
   NoteManager *m_manager;
   IKeybinder  *m_keybinder;
