@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,12 +24,11 @@
 #include <glibmm/i18n.h>
 
 #include "sharp/string.hpp"
-#include "gnote.hpp"
 #include "iconmanager.hpp"
 #include "notemanager.hpp"
 #include "notebooks/notebook.hpp"
 #include "notebooks/notebookmanager.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 
 namespace gnote {
 namespace notebooks {
@@ -44,7 +43,8 @@ namespace notebooks {
   /// A <see cref="System.String"/>.  This is the name that will be used
   /// to identify the notebook.
   /// </param>
-  Notebook::Notebook(const std::string & name, bool is_special)
+  Notebook::Notebook(NoteManager & manager, const std::string & name, bool is_special)
+    : m_note_manager(manager)
   {
     // is special assume the name as is, and we don't want a tag.
     if(is_special) {
@@ -52,7 +52,7 @@ namespace notebooks {
     }
     else {
       set_name(name);
-      m_tag = TagManager::obj().get_or_create_system_tag (
+      m_tag = ITagManager::obj().get_or_create_system_tag(
         std::string(NOTEBOOK_TAG_PREFIX) + name);
     }
   }
@@ -63,7 +63,8 @@ namespace notebooks {
   /// <param name="notebookTag">
   /// A <see cref="Tag"/>.  This must be a system notebook tag.
   /// </param>
-  Notebook::Notebook(const Tag::Ptr & notebookTag)
+  Notebook::Notebook(NoteManager & manager, const Tag::Ptr & notebookTag)
+    : m_note_manager(manager)
   {
   // Parse the notebook name from the tag name
     std::string systemNotebookPrefix = std::string(Tag::SYSTEM_TAG_PREFIX)
@@ -107,8 +108,8 @@ namespace notebooks {
   Note::Ptr Notebook::find_template_note() const
   {
     Note::Ptr note;
-    Tag::Ptr template_tag = TagManager::obj().get_system_tag (TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-    Tag::Ptr notebook_tag = TagManager::obj().get_system_tag (NOTEBOOK_TAG_PREFIX + get_name());
+    Tag::Ptr template_tag = ITagManager::obj().get_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    Tag::Ptr notebook_tag = ITagManager::obj().get_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
     if(!template_tag || !notebook_tag) {
       return note;
     }
@@ -126,32 +127,29 @@ namespace notebooks {
 
   Note::Ptr Notebook::get_template_note() const
   {
-    NoteManager & noteManager = Gnote::obj().default_note_manager();
     Note::Ptr note = find_template_note();
 
     if (!note) {
       std::string title = m_default_template_note_title;
-      if (noteManager.find(title)) {
+      if(m_note_manager.find(title)) {
         std::list<Note*> tag_notes;
         m_tag->get_notes(tag_notes);
-        title = noteManager.get_unique_name (title, tag_notes.size());
+        title = m_note_manager.get_unique_name (title, tag_notes.size());
       }
-      note =
-        noteManager.create (title,
-                            NoteManager::get_note_template_content (title));
+      note = m_note_manager.create(title, NoteManager::get_note_template_content (title));
           
       // Select the initial text
       NoteBuffer::Ptr buffer = note->get_buffer();
       buffer->select_note_body();
 
       // Flag this as a template note
-      Tag::Ptr template_tag = TagManager::obj().get_or_create_system_tag (TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+      Tag::Ptr template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
       note->add_tag (template_tag);
 
       // Add on the notebook system tag so Tomboy
       // will persist the tag/notebook across sessions
       // if no other notes are added to the notebook.
-      Tag::Ptr notebook_tag = TagManager::obj().get_or_create_system_tag (NOTEBOOK_TAG_PREFIX + get_name());
+      Tag::Ptr notebook_tag = ITagManager::obj().get_or_create_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
       note->add_tag (notebook_tag);
         
       note->queue_save (CONTENT_CHANGED);
@@ -164,10 +162,9 @@ namespace notebooks {
   {
     std::string temp_title;
     Note::Ptr note_template = get_template_note();
-    NoteManager & note_manager = Gnote::obj().default_note_manager();
 
-    temp_title = note_manager.get_unique_name(_("New Note"), note_manager.get_notes().size());
-    Note::Ptr note = note_manager.create_note_from_template(temp_title, note_template);
+    temp_title = m_note_manager.get_unique_name(_("New Note"), m_note_manager.get_notes().size());
+    Note::Ptr note = m_note_manager.create_note_from_template(temp_title, note_template);
 
     // Add the notebook tag
     note->add_tag(m_tag);
@@ -191,7 +188,7 @@ namespace notebooks {
 
   bool Notebook::add_note(const Note::Ptr & note)
   {
-    NotebookManager::instance().move_note_to_notebook(note, shared_from_this());
+    NotebookManager::obj().move_note_to_notebook(note, shared_from_this());
     return true;
   }
 
@@ -212,12 +209,12 @@ namespace notebooks {
 
   Note::Ptr SpecialNotebook::get_template_note() const
   {
-    return Gnote::obj().default_note_manager().get_or_create_template_note();
+    return m_note_manager.get_or_create_template_note();
   }
 
 
-  AllNotesNotebook::AllNotesNotebook()
-    : SpecialNotebook(_("All Notes"))
+  AllNotesNotebook::AllNotesNotebook(NoteManager & manager)
+    : SpecialNotebook(manager, _("All Notes"))
   {
   }
 
@@ -245,8 +242,8 @@ namespace notebooks {
   }
 
 
-  UnfiledNotesNotebook::UnfiledNotesNotebook()
-    : SpecialNotebook(_("Unfiled Notes"))
+  UnfiledNotesNotebook::UnfiledNotesNotebook(NoteManager & manager)
+    : SpecialNotebook(manager, _("Unfiled Notes"))
   {
   }
 
@@ -258,13 +255,13 @@ namespace notebooks {
 
   bool UnfiledNotesNotebook::contains_note(const Note::Ptr & note)
   {
-    return !notebooks::NotebookManager::instance().get_notebook_from_note(note);
+    return !notebooks::NotebookManager::obj().get_notebook_from_note(note);
   }
 
 
   bool UnfiledNotesNotebook::add_note(const Note::Ptr & note)
   {
-    NotebookManager::instance().move_note_to_notebook(note, Notebook::Ptr());
+    NotebookManager::obj().move_note_to_notebook(note, Notebook::Ptr());
     return true;
   }
 
@@ -274,8 +271,8 @@ namespace notebooks {
   }
 
 
-  PinnedNotesNotebook::PinnedNotesNotebook()
-    : SpecialNotebook(_("Pinned Notes"))
+  PinnedNotesNotebook::PinnedNotesNotebook(NoteManager & manager)
+    : SpecialNotebook(manager, _("Pinned Notes"))
   {
   }
 
@@ -302,10 +299,10 @@ namespace notebooks {
   }
 
 
-  ActiveNotesNotebook::ActiveNotesNotebook()
-    : SpecialNotebook(_("Active Notes"))
+  ActiveNotesNotebook::ActiveNotesNotebook(NoteManager & manager)
+    : SpecialNotebook(manager, _("Active Notes"))
   {
-    Gnote::obj().default_note_manager().signal_note_deleted
+    manager.signal_note_deleted
       .connect(sigc::mem_fun(*this, &ActiveNotesNotebook::on_note_deleted));
   }
 
