@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -36,9 +36,8 @@
 #include "notebooks/notebookmanager.hpp"
 #include "notebooks/notebooknewnotemenuitem.hpp"
 #include "notebooks/notebook.hpp"
-#include "actionmanager.hpp"
+#include "iactionmanager.hpp"
 #include "debug.hpp"
-#include "gnote.hpp"
 #include "iconmanager.hpp"
 #include "notemanager.hpp"
 
@@ -76,7 +75,7 @@ namespace gnote {
                              _("Notebooks"),
                              _("Create a new note in a notebook")));
           
-      ActionManager & am(ActionManager::obj());
+      IActionManager & am(IActionManager::obj());
       m_notebookUi = am.get_ui()->add_ui_from_string (uixml);
       
       am.get_ui()->insert_action_group (m_actionGroup, 0);
@@ -107,7 +106,7 @@ namespace gnote {
             IconManager::obj().get_icon(IconManager::NOTE_NEW, 16))));
       }
 
-      NoteManager & nm(Gnote::obj().default_note_manager());
+      NoteManager & nm(note_manager());
       
       for(Note::List::const_iterator iter = nm.get_notes().begin();
           iter != nm.get_notes().end(); ++iter) {
@@ -126,7 +125,7 @@ namespace gnote {
       am.add_app_action("new-notebook");
       am.get_app_action("new-notebook")->signal_activate().connect(
         sigc::mem_fun(*this, &NotebookApplicationAddin::on_new_notebook_action));
-      am.add_app_menu_item(ActionManager::APP_ACTION_NEW, 300, _("New Note_book"), "app.new-notebook");
+      am.add_app_menu_item(IActionManager::APP_ACTION_NEW, 300, _("New Note_book"), "app.new-notebook");
         
       m_initialized = true;
     }
@@ -134,7 +133,7 @@ namespace gnote {
 
     void NotebookApplicationAddin::shutdown ()
     {
-      ActionManager & am(ActionManager::obj());
+      IActionManager & am(IActionManager::obj());
       try {
         am.get_ui()->remove_action_group(m_actionGroup);
       } 
@@ -179,7 +178,7 @@ namespace gnote {
 
       NotebookNewNoteMenuItem *item;
 
-      Glib::RefPtr<Gtk::TreeModel> model = NotebookManager::instance().get_notebooks();
+      Glib::RefPtr<Gtk::TreeModel> model = NotebookManager::obj().get_notebooks();
       Gtk::TreeIter iter;
       
       // Add in the "New Notebook..." menu item
@@ -238,7 +237,7 @@ namespace gnote {
 
     void NotebookApplicationAddin::on_tag_added(const Note & note, const Tag::Ptr& tag)
     {
-      if (NotebookManager::instance().is_adding_notebook()) {
+      if (NotebookManager::obj().is_adding_notebook()) {
         return;
       }
       
@@ -252,9 +251,9 @@ namespace gnote {
         sharp::string_substring(tag->name(), megaPrefix.size());
       
       Notebook::Ptr notebook =
-        NotebookManager::instance().get_or_create_notebook (notebookName);
+        NotebookManager::obj().get_or_create_notebook (notebookName);
         
-      NotebookManager::instance().signal_note_added_to_notebook() (note, notebook);
+      NotebookManager::obj().signal_note_added_to_notebook() (note, notebook);
     }
 
     
@@ -273,12 +272,12 @@ namespace gnote {
         sharp::string_substring(normalizedTagName, megaPrefix.size());
       
       Notebook::Ptr notebook =
-        NotebookManager::instance().get_notebook (normalizedNotebookName);
+        NotebookManager::obj().get_notebook (normalizedNotebookName);
       if (!notebook) {
         return;
       }
       
-      NotebookManager::instance().signal_note_removed_from_notebook() (*note, notebook);
+      NotebookManager::obj().signal_note_removed_from_notebook() (*note, notebook);
     }
 
     void NotebookApplicationAddin::on_note_added(const Note::Ptr & note)
