@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2009 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -44,10 +44,11 @@
 #include "sharp/modulemanager.hpp"
 #include "sharp/propertyeditor.hpp"
 #include "synchronization/syncserviceaddin.hpp"
+#include "iactionmanager.hpp"
 #include "addinmanager.hpp"
 #include "addinpreferencefactory.hpp"
 #include "debug.hpp"
-#include "gnote.hpp"
+#include "ignote.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "preferencesdialog.hpp"
@@ -85,7 +86,7 @@ namespace gnote {
   };
 
 
-  PreferencesDialog::PreferencesDialog(AddinManager & addinmanager)
+  PreferencesDialog::PreferencesDialog(NoteManager & note_manager)
     : Gtk::Dialog()
     , m_sync_addin_combo(NULL)
     , m_selected_sync_addin(NULL)
@@ -94,7 +95,8 @@ namespace gnote {
     , m_reset_sync_addin_button(NULL)
     , m_save_sync_addin_button(NULL)
     , m_rename_behavior_combo(NULL)
-    , m_addin_manager(addinmanager)
+    , m_addin_manager(note_manager.get_addin_manager())
+    , m_note_manager(note_manager)
   {
 //    set_icon(utils::get_icon("gnote"));
     set_border_width(5);
@@ -251,7 +253,7 @@ namespace gnote {
         check = manage(make_check_button (
                          _("_Spell check while typing")));
         options_list->pack_start (*check, false, false, 0);
-        peditor = new sharp::PropertyEditorBool(Preferences::ENABLE_SPELLCHECKING, *check);
+        peditor = new sharp::PropertyEditorBool(settings, Preferences::ENABLE_SPELLCHECKING, *check);
         peditor->setup();
 
         label = manage(make_tip_label (
@@ -525,7 +527,7 @@ namespace gnote {
     // Populate the store with all the available SyncServiceAddins
     m_sync_addin_store = Gtk::ListStore::create(m_sync_addin_store_record);
     std::list<sync::SyncServiceAddin*> addins;
-    Gnote::obj().default_note_manager().get_addin_manager().get_sync_service_addins(addins);
+    m_addin_manager.get_sync_service_addins(addins);
     addins.sort(CompareSyncAddinsByName());
     for(std::list<sync::SyncServiceAddin*>::iterator addin = addins.begin(); addin != addins.end(); ++addin) {
       if((*addin)->initialized()) {
@@ -1032,11 +1034,10 @@ namespace gnote {
 
   void  PreferencesDialog::open_template_button_clicked()
   {
-    NoteManager &manager = Gnote::obj().default_note_manager();
-    Note::Ptr template_note = manager.get_or_create_template_note ();
+    Note::Ptr template_note = m_note_manager.get_or_create_template_note ();
 
     // Open the template note
-    Gnote::obj().open_note(template_note);
+    IGnote::obj().open_note(template_note);
   }
 
 
@@ -1243,7 +1244,7 @@ DBG_OUT("no addin");
     // Reset conflict handling behavior
     settings->set_int(Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, DEFAULT_SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
 
-    sync::SyncManager::obj().reset_client();
+    sync::ISyncManager::obj().reset_client();
 
     m_sync_addin_combo->set_sensitive(true);
     m_sync_addin_combo->unset_active();
@@ -1283,7 +1284,7 @@ DBG_OUT("no addin");
       m_reset_sync_addin_button->set_sensitive(true);
       m_save_sync_addin_button->set_sensitive(false);
 
-      sync::SyncManager::obj().reset_client();
+      sync::ISyncManager::obj().reset_client();
 
       // Give the user a visual letting them know that connecting
       // was successful.
@@ -1296,7 +1297,7 @@ DBG_OUT("no addin");
 
       if(dialog_response == Gtk::RESPONSE_YES) {
         // TODO: Put this voodoo in a method somewhere
-        ActionManager::obj().get_app_action("sync-notes")->activate(Glib::VariantBase());
+        IActionManager::obj().get_app_action("sync-notes")->activate(Glib::VariantBase());
       }
     }
     else {
