@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -45,7 +45,7 @@ class PreferencesDialog
   : public Gtk::Dialog
 {
 public:
-  PreferencesDialog(AddinManager & addinmanager);
+  explicit PreferencesDialog(NoteManager & note_manager);
   
 
   Gtk::Widget *make_editing_pane();
@@ -119,6 +119,7 @@ private:
   Gtk::SpinButton *m_autosync_spinner;
   Gtk::ComboBoxText *m_rename_behavior_combo;
   AddinManager &m_addin_manager;
+  NoteManager & m_note_manager;
     
   Gtk::Button *font_button;
   Gtk::Label  *font_face;
