@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -22,6 +22,7 @@
 
 #include <boost/format.hpp>
 #include <glibmm/i18n.h>
+#include <gtkmm/alignment.h>
 #include <gtkmm/linkbutton.h>
 #include <gtkmm/liststore.h>
 #include <gtkmm/separatormenuitem.h>
@@ -35,15 +36,13 @@
 #include "recenttreeview.hpp"
 #include "search.hpp"
 #include "searchnoteswidget.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 #include "notebooks/notebookmanager.hpp"
 #include "sharp/string.hpp"
 
 
 namespace gnote {
 
-std::list<std::string> SearchNotesWidget::s_previous_searches;
-
 
 Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon()
 {
@@ -54,9 +53,6 @@ Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon()
 SearchNotesWidget::SearchNotesWidget(NoteManager & m)
   : Gtk::VBox(false, 0)
   , m_accel_group(Gtk::AccelGroup::create())
-  , m_find_combo(Glib::RefPtr<Gtk::TreeModel>::cast_static(Gtk::ListStore::create(m_find_combo_columns)), true)
-  , m_clear_search_button(Gtk::Stock::CLEAR)
-  , m_entry_changed_timeout(NULL)
   , m_no_matches_box(NULL)
   , m_manager(m)
   , m_clickX(0), m_clickY(0)
@@ -67,44 +63,6 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
 {
   make_actions();
 
-  Gtk::Label *label = manage(new Gtk::Label (_("_Search:"), true));
-  label->property_xalign() = 1;
-
-  label->set_mnemonic_widget(m_find_combo);
-  m_find_combo.set_entry_text_column(0);
-  m_find_combo.signal_changed()
-    .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_entry_changed));
-  m_find_combo.get_entry()->set_activates_default(false);
-  m_find_combo.get_entry()->signal_activate()
-    .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_entry_activated));
-
-  Glib::RefPtr<Gtk::ListStore> model
-    = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_find_combo.get_model());
-  for(std::list<std::string>::const_iterator liter = s_previous_searches.begin();
-      liter != s_previous_searches.end(); ++liter) {
-    Gtk::TreeIter iter = model->append();
-    iter->set_value(0, *liter);
-  }
-
-  m_clear_search_button.set_sensitive(false);
-  m_clear_search_button.signal_clicked()
-    .connect(sigc::mem_fun(*this, &SearchNotesWidget::clear_search_clicked));
-  m_clear_search_button.show();
-
-  Gtk::Table *table = manage(new Gtk::Table(2, 3, false));
-  table->attach(*label, 0, 1, 0, 1, Gtk::SHRINK, (Gtk::AttachOptions)0, 0, 0);
-  table->attach(m_find_combo, 1, 2, 0, 1);
-  table->attach(m_clear_search_button,
-                2, 3, 0, 1,
-                Gtk::SHRINK, (Gtk::AttachOptions)0, 0, 0);
-  table->property_column_spacing() = 4;
-  table->set_border_width(6);
-  table->show_all();
-
-  Gtk::HBox *hbox = manage(new Gtk::HBox(false, 2));
-  hbox->pack_start(*table, true, true, 0);
-  hbox->show_all();
-
   // Notebooks Pane
   Gtk::Widget *notebooksPane = Gtk::manage(make_notebooks_pane());
   notebooksPane->show();
@@ -129,7 +87,6 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
 
   restore_position();
 
-  pack_start(*hbox, false, false, 0);
   pack_start(m_hpaned, true, true, 0);
 
   // Update on changes to notes
@@ -141,42 +98,16 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
   // Watch when notes are added to notebooks so the search
   // results will be updated immediately instead of waiting
   // until the note's queue_save () kicks in.
-  notebooks::NotebookManager::instance().signal_note_added_to_notebook()
+  notebooks::NotebookManager::obj().signal_note_added_to_notebook()
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_added_to_notebook));
-  notebooks::NotebookManager::instance().signal_note_removed_from_notebook()
+  notebooks::NotebookManager::obj().signal_note_removed_from_notebook()
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_removed_from_notebook));
-  notebooks::NotebookManager::instance().signal_note_pin_status_changed
+  notebooks::NotebookManager::obj().signal_note_pin_status_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
-
-  // Set the focus chain for the top-most containers
-  std::vector<Gtk::Widget*> focus_chain;
-  focus_chain.push_back(hbox);
-  focus_chain.push_back(&m_hpaned);
-  set_focus_chain(focus_chain);
-
-  // Set focus chain for sub widgets of first top-most container
-  focus_chain.clear();
-  focus_chain.push_back(&m_find_combo);
-  focus_chain.push_back(&m_matches_window);
-  hbox->set_focus_chain(focus_chain);
-
-  // set focus chain for sub widgets of second top-most container
-  focus_chain.clear();
-  focus_chain.push_back(&m_matches_window);
-  focus_chain.push_back(notebooksPane);
-  m_hpaned.set_focus_chain(focus_chain);
-
-  // get back to the beginning of the focus chain
-  focus_chain.clear();
-  focus_chain.push_back(m_tree);
-  m_matches_window.set_focus_chain(focus_chain);
 }
 
 SearchNotesWidget::~SearchNotesWidget()
 {
-  if(m_entry_changed_timeout) {
-    delete m_entry_changed_timeout;
-  }
   if(m_note_list_context_menu) {
     delete m_note_list_context_menu;
   }
@@ -211,66 +142,11 @@ void SearchNotesWidget::make_actions()
   m_delete_notebook_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_delete_notebook));
 }
 
-void SearchNotesWidget::focus_search_entry()
+void SearchNotesWidget::perform_search(const std::string & search_text)
 {
-  m_find_combo.get_entry()->grab_focus();
-}
-
-void SearchNotesWidget::on_entry_changed()
-{
-  if(m_entry_changed_timeout == NULL) {
-    m_entry_changed_timeout = new utils::InterruptableTimeout();
-    m_entry_changed_timeout->signal_timeout
-      .connect(sigc::mem_fun(*this, &SearchNotesWidget::entry_changed_timeout));
-  }
-
-  if(get_search_text().empty()) {
-    m_clear_search_button.set_sensitive(false);
-    perform_search();
-  }
-  else {
-    m_entry_changed_timeout->reset(500);
-    m_clear_search_button.set_sensitive(true);
-  }
-
   restore_matches_window();
-}
-
-void SearchNotesWidget::on_entry_activated()
-{
-  if(m_entry_changed_timeout) {
-    m_entry_changed_timeout->cancel();
-  }
-
-  entry_changed_timeout();
-}
-
-void SearchNotesWidget::clear_search_clicked()
-{
-  m_find_combo.get_entry()->set_text("");
-  m_find_combo.get_entry()->grab_focus ();
-}
-
-void SearchNotesWidget::entry_changed_timeout()
-{
-  if(get_search_text().empty()) {
-    return;
-  }
-
+  m_search_text = search_text;
   perform_search();
-  add_to_previous_searches(get_search_text());
-}
-
-std::string SearchNotesWidget::get_search_text()
-{
-  // Entry may be null if search window closes
-  // early (bug #544996).
-  if (m_find_combo.get_entry() == NULL) {
-    return NULL;
-  }
-  std::string text = m_find_combo.get_entry()->get_text();
-  text = sharp::string_trim(text);
-  return text;
 }
 
 void SearchNotesWidget::perform_search()
@@ -280,7 +156,7 @@ void SearchNotesWidget::perform_search()
   remove_matches_column();
   Search search(m_manager);
 
-  std::string text = get_search_text();
+  std::string text = m_search_text;
   if(text.empty()) {
     m_current_matches.clear();
     m_store_filter->refilter();
@@ -326,32 +202,11 @@ void SearchNotesWidget::restore_matches_window()
   }
 }
 
-void SearchNotesWidget::add_to_previous_searches(const std::string & text)
-{
-  // Update previous searches, by adding a new term to the
-  // list, or shuffling an existing term to the top...
-  bool repeat = false;
-
-  std::string lower = sharp::string_to_lower(text);
-  for(std::list<std::string>::const_iterator iter = s_previous_searches.begin();
-      iter != s_previous_searches.end(); ++iter) {
-    if (sharp::string_to_lower(*iter) == lower) {
-      repeat = true;
-    }
-  }
-
-  if (!repeat) {
-    s_previous_searches.push_front(text);
-    Gtk::TreeIter iter
-      = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_find_combo.get_model())->prepend();
-    iter->set_value(0, text);
-  }
-}
-
 Gtk::Widget *SearchNotesWidget::make_notebooks_pane()
 {
   m_notebooksTree = Gtk::manage(
-    new notebooks::NotebooksTreeView(notebooks::NotebookManager::instance()
+    new notebooks::NotebooksTreeView(m_manager,
+                                     notebooks::NotebookManager::obj()
                                        .get_notebooks_with_special_items()));
 
   m_notebooksTree->get_selection()->set_mode(Gtk::SELECTION_SINGLE);
@@ -507,26 +362,26 @@ void SearchNotesWidget::notebook_text_cell_data_func(Gtk::CellRenderer * rendere
 void SearchNotesWidget::on_notebook_row_edited(const Glib::ustring& /*tree_path*/,
                                                const Glib::ustring& new_text)
 {
-  if(notebooks::NotebookManager::instance().notebook_exists(new_text) || new_text == "") {
+  if(notebooks::NotebookManager::obj().notebook_exists(new_text) || new_text == "") {
     return;
   }
   notebooks::Notebook::Ptr old_notebook = this->get_selected_notebook();
   if(std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(old_notebook)) {
     return;
   }
-  notebooks::Notebook::Ptr new_notebook = notebooks::NotebookManager::instance()
+  notebooks::Notebook::Ptr new_notebook = notebooks::NotebookManager::obj()
     .get_or_create_notebook(new_text);
   DBG_OUT("Renaming notebook '{%s}' to '{%s}'", old_notebook->get_name().c_str(),
           new_text.c_str());
   std::list<Note *> notes;
   old_notebook->get_tag()->get_notes(notes);
   for(std::list<Note *>::const_iterator note = notes.begin(); note != notes.end(); ++note) {
-    notebooks::NotebookManager::instance().move_note_to_notebook(
+    notebooks::NotebookManager::obj().move_note_to_notebook(
       (*note)->shared_from_this(), new_notebook);
   }
-  notebooks::NotebookManager::instance().delete_notebook(old_notebook);
+  notebooks::NotebookManager::obj().delete_notebook(old_notebook);
   Gtk::TreeIter iter;
-  if(notebooks::NotebookManager::instance().get_notebook_iter(new_notebook, iter)) {
+  if(notebooks::NotebookManager::obj().get_notebook_iter(new_notebook, iter)) {
     m_notebooksTree->get_selection()->select(iter);
   }
 }
@@ -744,7 +599,7 @@ bool SearchNotesWidget::filter_notes(const Gtk::TreeIter & iter)
   }
 
   // Don't show the template notes in the list
-  Tag::Ptr template_tag = TagManager::obj().get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+  Tag::Ptr template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
   if(note->contains_tag(template_tag)) {
     return false;
   }
@@ -928,7 +783,7 @@ Note::Ptr SearchNotesWidget::get_note(const Gtk::TreePath & p)
 
 bool SearchNotesWidget::filter_by_search(const Note::Ptr & note)
 {
-  if(get_search_text().empty()) {
+  if(m_search_text.empty()) {
     return true;
   }
 
@@ -1427,13 +1282,6 @@ Gtk::Window *SearchNotesWidget::get_owning_window()
   return dynamic_cast<Gtk::Window*>(widget);
 }
 
-void SearchNotesWidget::set_search_text(const std::string & value)
-{
-  if(!value.empty()) {
-    m_find_combo.get_entry()->set_text(value);
-  }
-}
-
 void SearchNotesWidget::on_note_added_to_notebook(const Note &,
                                                   const notebooks::Notebook::Ptr &)
 {
