@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -25,7 +25,6 @@
 
 #include <set>
 
-#include <gtkmm/combobox.h>
 #include <gtkmm/box.h>
 #include <gtkmm/liststore.h>
 #include <gtkmm/paned.h>
@@ -50,24 +49,17 @@ public:
   virtual void foreground();
   virtual void background();
 
-  void focus_search_entry();
+  void perform_search(const std::string & search_text);
   void select_all_notes_notebook();
   void new_note();
   void delete_selected_notes();
-  void set_search_text(const std::string & value);
 
   sigc::signal<void, const Note::Ptr &> signal_open_note;
   sigc::signal<void, const Note::Ptr &> signal_open_note_new_window;
 private:
   void make_actions();
-  void on_entry_changed();
-  void on_entry_activated();
-  void clear_search_clicked();
-  void entry_changed_timeout();
-  std::string get_search_text();
   void perform_search();
   void restore_matches_window();
-  void add_to_previous_searches(const std::string &);
   Gtk::Widget *make_notebooks_pane();
   void restore_position();
   void save_position();
@@ -155,10 +147,7 @@ private:
   Glib::RefPtr<Gtk::Action> m_delete_note_action;
   Glib::RefPtr<Gtk::Action> m_delete_notebook_action;
   RecentSearchColumnTypes m_find_combo_columns;
-  Gtk::ComboBox m_find_combo;
-  Gtk::Button m_clear_search_button;
   Gtk::HPaned m_hpaned;
-  utils::InterruptableTimeout *m_entry_changed_timeout;
   Gtk::ScrolledWindow m_matches_window;
   Gtk::HBox *m_no_matches_box;
   notebooks::NotebooksTreeView *m_notebooksTree;
@@ -177,10 +166,9 @@ private:
   Gtk::Menu *m_note_list_context_menu;
   Gtk::Menu *m_notebook_list_context_menu;
   bool m_initial_position_restored;
+  std::string m_search_text;
 
   static Glib::RefPtr<Gdk::Pixbuf> get_note_icon();
-
-  static std::list<std::string> s_previous_searches;
 };
 
 }
