@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,13 +37,13 @@
 #include "actionmanager.hpp"
 #include "iconmanager.hpp"
 #include "utils.hpp"
-#include "gnote.hpp"
+#include "ignote.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "prefskeybinder.hpp"
 #include "tag.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 #include "preferences.hpp"
 #include "sharp/datetime.hpp"
 #include "sharp/string.hpp"
@@ -93,9 +93,9 @@ namespace gnote {
   {
     if(!m_inhibit_activate) {
       if(m_note) {
-        NoteRecentChanges *window = Gnote::obj().get_window_for_note();
-        window->present_note(m_note);
-        window->present();
+        MainWindow & window = IGnote::obj().get_window_for_note();
+        window.present_note(m_note);
+        window.present();
       }
     }
   }
@@ -195,10 +195,11 @@ namespace gnote {
     return IconManager::obj().get_icon(IconManager::PIN_DOWN, 16);
   }
 
-  Tray::Tray(NoteManager & manager, IGnoteTray & trayicon)
+  Tray::Tray(NoteManager & manager, IGnoteTray & trayicon, IKeybinder & keybinder)
     : m_manager(manager)
     , m_trayicon(trayicon)
     , m_menu_added(false)
+    , m_keybinder(keybinder)
   {
 
     m_tray_menu = make_tray_notes_menu();
@@ -208,7 +209,7 @@ namespace gnote {
   {
     Gtk::Menu *menu;
 
-    ActionManager & am(ActionManager::obj());
+    IActionManager & am(IActionManager::obj());
     
     menu = (Gtk::Menu*)am.get_widget("/TrayIconMenu");
     DBG_ASSERT(menu, "menu not found");
@@ -218,15 +219,15 @@ namespace gnote {
     if (enable_keybindings) {
       Gtk::MenuItem *item = (Gtk::MenuItem*)am.get_widget("/TrayIconMenu/TrayNewNotePlaceholder/TrayNewNote");
       if(item) {
-        KeybindingToAccel::add_accelerator(*item, Preferences::KEYBINDING_CREATE_NEW_NOTE);
+        KeybindingToAccel::add_accelerator(m_keybinder, *item, Preferences::KEYBINDING_CREATE_NEW_NOTE);
       }
       item = (Gtk::MenuItem*)am.get_widget("/TrayIconMenu/ShowSearchAllNotes");
       if(item) {
-        KeybindingToAccel::add_accelerator(*item, Preferences::KEYBINDING_OPEN_RECENT_CHANGES);
+        KeybindingToAccel::add_accelerator(m_keybinder, *item, Preferences::KEYBINDING_OPEN_RECENT_CHANGES);
       }
       item = (Gtk::MenuItem*)am.get_widget("/TrayIconMenu/OpenStartHereNote");
       if(item) {
-        KeybindingToAccel::add_accelerator(*item, Preferences::KEYBINDING_OPEN_START_HERE);
+        KeybindingToAccel::add_accelerator(m_keybinder, *item, Preferences::KEYBINDING_OPEN_START_HERE);
       }
     }
 
@@ -271,7 +272,7 @@ namespace gnote {
     remove_recently_changed_notes();
 
     // Assume menu opens downward, move common items to top of menu
-    ActionManager & am(ActionManager::obj());
+    ActionManager & am(static_cast<ActionManager &>(IActionManager::obj()));
     Gtk::MenuItem* newNoteItem = (Gtk::MenuItem*)am.get_widget(
       "/TrayIconMenu/TrayNewNotePlaceholder/TrayNewNote");
     Gtk::MenuItem* searchNotesItem = (Gtk::MenuItem*)am.get_widget(
@@ -303,8 +304,8 @@ namespace gnote {
     days_ago.add_days(-3);
 
     // Prevent template notes from appearing in the menu
-    Tag::Ptr template_tag = TagManager::obj()
-      .get_or_create_system_tag(TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    Tag::Ptr template_tag = ITagManager::obj()
+      .get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
 
     // List the most recently changed notes, any currently
     // opened notes, and any pinned notes...
@@ -367,7 +368,7 @@ namespace gnote {
       bool enable_keybindings = Preferences::obj().get_schema_settings(
           Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::ENABLE_KEYBINDINGS);
       if (enable_keybindings) {
-        KeybindingToAccel::add_accelerator(*item, Preferences::KEYBINDING_OPEN_START_HERE);
+        KeybindingToAccel::add_accelerator(m_keybinder, *item, Preferences::KEYBINDING_OPEN_START_HERE);
       }
     }
 
@@ -393,16 +394,16 @@ namespace gnote {
     m_recent_notes.push_back(separator);
   }
 
-  TrayIcon::TrayIcon(NoteManager & manager)
+  TrayIcon::TrayIcon(IKeybinder & keybinder, NoteManager & manager)
     : Gtk::StatusIcon()
-    , m_tray(new Tray(manager, *this))
-    , m_keybinder(new GnotePrefsKeybinder(manager, *this))
+    , m_tray(new Tray(manager, *this, keybinder))
+    , m_keybinder(new GnotePrefsKeybinder(keybinder, manager, *this))
     , m_context_menu(NULL)
   {
     gtk_status_icon_set_tooltip_text(gobj(), 
                                      tray_util_get_tooltip_text().c_str());
 
-    Gnote::obj().signal_quit.connect(sigc::mem_fun(*this, &TrayIcon::on_exit));
+    IGnote::obj().signal_quit.connect(sigc::mem_fun(*this, &TrayIcon::on_exit));
     signal_activate().connect(sigc::mem_fun(*this, &TrayIcon::on_activate));
     signal_popup_menu().connect(sigc::mem_fun(*this, &TrayIcon::on_popup_menu));
   }
@@ -586,12 +587,12 @@ namespace gnote {
     return "";
   }
 
-  void KeybindingToAccel::add_accelerator (Gtk::MenuItem & item, const std::string & key)
+  void KeybindingToAccel::add_accelerator(IKeybinder & keybinder, Gtk::MenuItem & item, const std::string & key)
   {
     guint keyval;
     Gdk::ModifierType mods;
 
-    if(Gnote::obj().keybinder().get_accel_keys(key, keyval, mods)) {
+    if(keybinder.get_accel_keys(key, keyval, mods)) {
       item.add_accelerator ("activate",
                              get_accel_group(),
                              keyval,
