@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -58,6 +58,9 @@ namespace gnote {
                                      const std::string & error);
     std::string get_pretty_print_date(const sharp::DateTime &, bool show_time);
 
+    void main_context_invoke(const sigc::slot<void> & slot);
+    void main_context_call(const sigc::slot<void> & slot);
+
     class GlobalKeybinder
     {
     public:
@@ -258,6 +261,10 @@ namespace gnote {
       virtual std::string get_name() const = 0;
       virtual void embed(EmbeddableWidgetHost *h)
         {
+          //remove from previous host, if any
+          if(m_host) {
+            m_host->unembed_widget(*this);
+          }
           m_host = h;
           signal_embedded();
         }
